@@ -1,3 +1,16 @@
+#   Copyright  2020 Atos Spain SA. All rights reserved.
+ 
+#   This file is part of EASIER AI.
+ 
+#   EASIER AI is free software: you can redistribute it and/or modify it under the terms of Apache License, either version 2 of the License, or
+#   (at your option) any later version.
+ 
+#   THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT ANY WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
+#   BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT,
+#   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+#   WHETHER IN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+#   OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+#   See  LICENSE file for full license information  in the project root.
 import os
 import sys
 import tempfile
@@ -316,7 +329,7 @@ def save_model(eslib, id, metadata, dict={}, inference_type=constants.ESTIMATOR,
         if save_tflite and calibration_data is not None:
             success = edge_toolkit.convert_model_lite(calibration_data=calibration_data, model_name=filename, keras_model=dict[constants.MODEL_EXTENSION])
             if success:
-                uploaded = upload_file_to_minio(config['ELASTIC']['index_models'], filename, constants.TF_LITE_EXTENSION, id, config['ML']['algorithm'])
+                uploaded = upload_file_to_minio(os.getenv('TRAINING_RESULTS_ID', config['ELASTIC']['index_models']), filename, constants.TF_LITE_EXTENSION, id, config['ML']['algorithm'])
                 if not uploaded:
                     _logger.error('Error on uploading file to min.io filesystem(' + filename + '.' + constants.TF_LITE_EXTENSION + ') - ')
                     return ''
@@ -325,7 +338,7 @@ def save_model(eslib, id, metadata, dict={}, inference_type=constants.ESTIMATOR,
         if save_tpu and calibration_data is not None:
             success = edge_toolkit.convert_model_tpu(calibration_data=calibration_data, model_name=filename, keras_model=dict[constants.MODEL_EXTENSION])
             if success:
-                uploaded = upload_file_to_minio(config['ELASTIC']['index_models'], filename + "_edgetpu", constants.TF_LITE_EXTENSION, id, config['ML']['algorithm'])
+                uploaded = upload_file_to_minio(os.getenv('TRAINING_RESULTS_ID', config['ELASTIC']['index_models']), filename + "_edgetpu", constants.TF_LITE_EXTENSION, id, config['ML']['algorithm'])
                 if not uploaded:
                     _logger.error('Error on uploading file to min.io filesystem(' + filename + "_edgetpu." + constants.TF_LITE_EXTENSION + ') - ')
                     return ''
